==> haskell-rere-0.2-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rere.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rere
version:              0.2
visibility:           public
id:                   rere-0.2-8YJE5YwSWMw1Tzg9g0VEiD
key:                  rere-0.2-8YJE5YwSWMw1Tzg9g0VEiD
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  82fcf39a3325e3ac37a4db7fb87babb8
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.0.1/site-local/rere-0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/rere-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/rere-0.2
hs-libraries:         HSrere-0.2-8YJE5YwSWMw1Tzg9g0VEiD
depends:
    QuickCheck-2.14.2-4fFmALdK9KzLSVxePLHYEq base-4.15.0.0
    containers-0.6.4.1 fin-0.2-9y47fbmYx8Q3epRcGZDkxu parsec-3.1.14.0
    transformers-0.5.6.2 vec-0.4-5h2wULTzpEWDTIfs3iXeJY

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rere-0.2-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rere.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rere
version:              0.2
visibility:           public
id:                   rere-0.2-67Bn9rwsZow3KWAw7bvDwl
key:                  rere-0.2-67Bn9rwsZow3KWAw7bvDwl
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:
    Regular-expressions extended with fixpoints for context-free powers

description:
    By extending regular expressions with (explicit) fixed points
    we can recognize context-free grammars.

category:             Parsing
abi:                  cc9dc3c8f754c90f5bbf9731b3bd9a17
exposed:              True
exposed-modules:
    RERE RERE.Absurd RERE.CFG RERE.CharClasses RERE.CharSet
    RERE.Examples RERE.Examples.JSON RERE.Gen RERE.LaTeX RERE.Ref
    RERE.ST RERE.Type RERE.Var

hidden-modules:       RERE.Tuples
import-dirs:          /usr/lib/ghc-9.0.1/site-local/rere-0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/rere-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/rere-0.2
hs-libraries:         HSrere-0.2-67Bn9rwsZow3KWAw7bvDwl
depends:
    QuickCheck-2.14.2-4xShtyX33BN5pkZj6nk754 base-4.15.0.0
    containers-0.6.4.1 fin-0.2-2GPTjsgrZ2x5xbgtD6tqKn parsec-3.1.14.0
    transformers-0.5.6.2 vec-0.4-D62dmiF5PXP4PFCH4cwxOG

haddock-interfaces:   /usr/share/doc/haskell-rere/html/rere.haddock
haddock-html:         /usr/share/doc/haskell-rere/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
